# ListUserGuidsResponse

Response object for user GUID query
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_ids** | **list[str]** | A list of user GUIDs | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


